SSLCCustomerInfoInitializer class

Annotations
  • @JsonSerializable.new()

Constructors

SSLCCustomerInfoInitializer({required String customerName, required String customerEmail, required String customerAddress1, String? customerAddress2, required String customerCity, required String customerState, required String customerPostCode, required String customerCountry, required String customerPhone, String? customerFax})
SSLCCustomerInfoInitializer.fromJson(Map<String, dynamic> json)
factory

Properties

customerAddress1 ↔ String
getter/setter pair
customerAddress2 ↔ String?
getter/setter pair
customerCity ↔ String
getter/setter pair
customerCountry ↔ String
getter/setter pair
customerEmail ↔ String
getter/setter pair
customerFax ↔ String?
getter/setter pair
customerName ↔ String
getter/setter pair
customerPhone ↔ String
getter/setter pair
customerPostCode ↔ String
getter/setter pair
customerState ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAddress2(String customerAddress2) → SSLCCustomerInfoInitializer
addFax(String customerFax) → SSLCCustomerInfoInitializer
addState(String customerState) → SSLCCustomerInfoInitializer
getCustomerAddress1() → String
getCustomerAddress2() → String?
getCustomerCity() → String
getCustomerCountry() → String
getCustomerEmail() → String
getCustomerFax() → String?
getCustomerName() → String
getCustomerPhone() → String
getCustomerPostCode() → String
getCustomerState() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomerAddress1(String customerAddress1) → void
setCustomerAddress2(String customerAddress2) → void
setCustomerCity(String customerCity) → void
setCustomerCountry(String customerCountry) → void
setCustomerEmail(String customerEmail) → void
setCustomerFax(String customerFax) → void
setCustomerName(String customerName) → void
setCustomerPhone(String customerPhone) → void
setCustomerPostCode(String customerPostCode) → void
setCustomerState(String customerState) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited