SSLCEMITransactionInitializer class

Annotations
  • @JsonSerializable.new()

Constructors

SSLCEMITransactionInitializer({required int emi_options, int? emi_max_list_options, int? emi_selected_inst})
SSLCEMITransactionInitializer.fromJson(Map<String, dynamic> json)
factory

Properties

emi_max_list_options ↔ int?
getter/setter pair
emi_options ↔ int
getter/setter pair
emi_selected_inst ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEmi_max_list_options() → int?
getEmi_options() → int
getEmi_selected_inst() → int?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEmi_max_list_options(int emi_max_list_options) → void
setEmi_options(int emi_options) → void
setEmi_selected_inst(int emi_selected_inst) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited