SSLCShipmentInfoInitializer class

Annotations
  • @JsonSerializable.new()

Constructors

SSLCShipmentInfoInitializer({required String shipmentMethod, required int? numOfItems, required ShipmentDetails shipmentDetails})
SSLCShipmentInfoInitializer.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
numOfItems ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipAddress2 ↔ String?
getter/setter pair
shipmentDetails ↔ ShipmentDetails
getter/setter pair
shipmentMethod ↔ String
getter/setter pair
shipState ↔ String?
getter/setter pair

Methods

addShipAddress2(String shipAddress2) → SSLCShipmentInfoInitializer
addShipState(String shipState) → SSLCShipmentInfoInitializer
getNumOfItems() → int?
getShipAddress2() → String
getShipmentDetails() → ShipmentDetails
getShipmentMethod() → String
getShipState() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNumOfItems(int numOfItems) → void
setShipAddress2(String shipAddress2) → void
setShipmentDetails(ShipmentDetails shipmentDetails) → void
setShipmentMethod(String shipmentMethod) → void
setShipState(String shipState) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited