ShipmentDetails class

Annotations
  • @JsonSerializable.new()

Constructors

ShipmentDetails({required String shipName, required String shipAddress1, required String shipCity, required String shipPostCode, required String shipCountry})
ShipmentDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipAddress1 ↔ String
getter/setter pair
shipCity ↔ String
getter/setter pair
shipCountry ↔ String
getter/setter pair
shipName ↔ String
getter/setter pair
shipPostCode ↔ String
getter/setter pair

Methods

getShipAddress1() → String
getShipCity() → String
getShipCountry() → String
getShipName() → String
getShipPostCode() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setShipAddress1(String shipAddress1) → void
setShipCity(String shipCity) → void
setShipCountry(String shipCountry) → void
setShipName(String shipName) → void
setShipPostCode(String shipPostCode) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited