General class

Annotations
  • @JsonSerializable.new()

Constructors

General({required String productProfile, required String general})
General.fromJson(Map<String, dynamic> json)
factory

Properties

general ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
productProfile ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getGeneral() → String
getProductProfile() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setGeneral(String general) → void
setProductProfile(String productProfile) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited