NonPhysicalGoods class

Annotations
  • @JsonSerializable.new()

Constructors

NonPhysicalGoods({required String productProfile, required String nonPhysicalGoods})
NonPhysicalGoods.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nonPhysicalGoods ↔ String
getter/setter pair
productProfile ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getNonPhysicalGoods() → String
getProductProfile() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNonPhysicalGoods(String nonPhysicalGoods) → void
setProductProfile(String productProfile) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited