PhysicalGoods class

Annotations
  • @JsonSerializable.new()

Constructors

PhysicalGoods({required String productProfile, required String physicalGoods})
PhysicalGoods.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
physicalGoods ↔ String
getter/setter pair
productProfile ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPhysicalGoods() → String
getProductProfile() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPhysicalGoods(String physicalGoods) → void
setProductProfile(String productProfile) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited