TelecomVertical class

Annotations
  • @JsonSerializable.new()

Constructors

TelecomVertical({required String productProfile, required String productType, required String topUpNumber, required String countryTopUp})
TelecomVertical.fromJson(Map<String, dynamic> json)
factory

Properties

countryTopUp ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
productProfile ↔ String
getter/setter pair
productType ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topUpNumber ↔ String
getter/setter pair

Methods

getCountryTopUp() → String
getProductProfile() → String
getProductType() → String
getTopUpNumber() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCountryTopUp(String countryTopUp) → void
setProductProfile(String productProfile) → void
setProductType(String productType) → void
setTopUpNumber(String topUpNumber) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited