TravelVertical class

Annotations
  • @JsonSerializable.new()

Constructors

TravelVertical({required String productProfile, required String hotelName, required String lengthOfStay, required String checkInTime, required String hotelCity})
TravelVertical.fromJson(Map<String, dynamic> json)
factory

Properties

checkInTime ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hotelCity ↔ String
getter/setter pair
hotelName ↔ String
getter/setter pair
lengthOfStay ↔ String
getter/setter pair
productProfile ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCheckInTime() → String
getHotelCity() → String
getHotelName() → String
getLengthOfStay() → String
getProductProfile() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCheckInTime(String checkInTime) → void
setHotelCity(String hotelCity) → void
setHotelName(String hotelName) → void
setLengthOfStay(String lengthOfStay) → void
setProductProfile(String productProfile) → void
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited